function P = calculo_penalizacion(Re,RIN,BER,B,L,D,AL,C,lambda)

% La funcin devuelve las prdidas por penalizacin
% P=penalizacin(Re,RIN,BER,B,L,D,AL,C,beta,lambda)
%   Re: relacin de extincin
%   RIN: ruido relativo de intensidad del lser
%   BER
%   B: tasa binaria (Gbps)
%   L: longitud de la fibra (km)
%   D: dispersin (ns/nm*km)
%   AL: ancho espectral de la fuente (nm)
%   C: chirp
%   lambda: longitud de onda del transmisor (nm)

% Penalizacin por relacin de extincin no nula
Per = -10*log10((Re-1)/(Re+1));
% Penalizacin por ruido de intensidad
q=erfcinv(BER/0.5)*sqrt(2);
Prin = -10*log10(1-(((10^(RIN/10))*((B*10^9)/2))*(q^2)));
% Penalizacin por dispersin cromtica
sigma_w=(2*pi*(3*(10^5))*AL)/(lambda^2);
sigma_o=1/(4*B*10^-3);
V=2*sigma_w*sigma_o;
beta=((D*(10^3)*(lambda^2))/(2*pi*(3*10^5)));
Pcd = 0;
if V > 1 % Para fuentes espectralmente anchas
    Pcd = -5*log10(1-(4*B*L*D*AL)^2);
elseif V < 1 % Para fuentes espectralmente estrechas
    Pcd = 5*log10(((1+8*C*beta*(B^2)*L)^2)+((8*beta*(B^2)*L)^2));
end
P = Per + Prin + Pcd;