function parametros_edificio(valor)
% Esta es la funcin en la cual definimos los parmetros de una finca,
% separacin entre las viviendas y se obtiene la longitud del tramo de
% fibra ms largo, que es sobre el cual se realizarn los clculos
% a: altura entre plantas (m)
% b y c: distancias entre cada ONT en la planta

if nargin<1,
    valor= 'comienzo';
end

global DATOS % Variable global que recoge los valores de los controles.
global variables distr n v e tramo_largo tramo_corto info_div ediv pr seg ter ...
    enl1 enl2 enl3 bp ep gp div2x2_1 div2x2_2 div2x2_3 % Estas son variables que almacenan informacin til
                                              % para las gui's siguientes.
if strcmp(valor,'comienzo'),
    
    color=[.7 .7 .7];
    % inicializamos los graficos
    set(gcf,'NumberTitle','off','position',[250,250,390,390],'Name','DiseoFTTH', ... 
        'menubar','none','backingstore','off','color',color,'Units','normalized');
    
    uicontrol('style','text','units','normalized','position',[.05 .93 .9 .04], ...
        'string','PARMETROS DEL EDIFICIO','backgroundcolor',[.5 .5 .5]);
    
    axes('units','normalized','position',[.05 .4 .9 .5]);
    [x,map]=imread('dibujo_edificio.png','png');
    image(x);colormap(map);axis off;hold on;
    
    uicontrol('style','text','units','normalized','position',[.05 .3 .37 .04], ...
        'string','a) Altura entre plantas (m):','backgroundcolor',color, ...
        'HorizontalAlignment','left');
    a = uicontrol('style','edit','units','normalized','string','3', ...
        'position',[.42 .304 .1 .04]);
    
    uicontrol('style','text','units','normalized','position',[.05 .25 .37 .04], ...
        'string','b) Separacin en planta (m):','backgroundcolor',color, ...
        'HorizontalAlignment','left');
    b = uicontrol('style','edit','units','normalized','string','15', ...
        'position',[.42 .254 .1 .04]);
    
    uicontrol('style','text','units','normalized','position',[.05 .2 .37 .04], ...
        'string','c) Separacin en planta (m):','backgroundcolor',color, ...
        'HorizontalAlignment','left');
    c = uicontrol('style','edit','units','normalized','string','10', ...
        'position',[.42 .204 .1 .04]);
    
    uicontrol('style','text','units','normalized','position',[.6 .3 .2 .04], ...
        'string','N de plantas:','backgroundcolor',color, ...
        'HorizontalAlignment','left');
    n = uicontrol('style','edit','units','normalized','string','5', ...
        'position',[.85 .304 .1 .04]);
    
    uicontrol('style','text','units','normalized','position',[.6 .25 .23 .04], ...
        'string','Viviendas/planta:','backgroundcolor',color, ...
        'HorizontalAlignment','left');
    v = uicontrol('style','edit','units','normalized','string','4', ...
        'position',[.85 .254 .1 .04]);
    
    uicontrol('style','text','units','normalized','position',[.6 .2 .23 .04], ...
        'string','N de edificios:','backgroundcolor',color, ...
        'HorizontalAlignment','left');
    e = uicontrol('style','edit','units','normalized','string','1', ...
        'position',[.85 .204 .1 .04]);
        
    div_ed = uicontrol('style','radio','units','normalized','string','Un divisor por edificio', ...
        'position',[.1 .14 .6 .04],'backgroundcolor',color,'value',1,...
        'CallBack','parametros_edificio(''div_ed'')');
    
    div_pl = uicontrol('style','radio','units','normalized','string','Un divisor por planta', ...
        'position',[.55 .14 .6 .04],'backgroundcolor',color,...
        'CallBack','parametros_edificio(''div_pl'')');

    uicontrol('Style','Pushbutton','Units','normalized','Position',[.2 .05 .15 .05], ...
              'String','AYUDA','BackgroundColor',color, ...
              'CallBack','parametros_edificio(''ayuda'')');
    
    uicontrol('Style','Pushbutton','Units','normalized','Position',[.4 .05 .15 .05], ...
              'String','OK','BackgroundColor',color, ...
              'CallBack','parametros_edificio(''ok'')');
          
    uicontrol('Style','Pushbutton','Units','normalized','Position',[.6 .05 .15 .05], ...
              'String','VOLVER','BackgroundColor',color, ...
              'CallBack','parametros_edificio(''volver'')');
    
    DATOS=[a b c n v e div_ed div_pl];      
    
    % Tan solo puede estar marcada una de las opciones
elseif strcmp(valor,'div_ed'),
    set(DATOS(8),'value',0);
elseif strcmp(valor,'div_pl'),
    set(DATOS(7),'value',0);
elseif strcmp(valor,'ayuda'),
    % AL pulsar el boton de AYUDA, se muestra una ventana con la
    % explicacin de esta parte de la aplicacin
    msgbox({'En este panel el usuario puede definir los parmetros del edificio, asi como la cantidad de estos.';...
        ' ';...
        'Hay dos botones referentes a la posicin del divisor o de los divisores pticos en el edificio:';...
        '- El primero de ellos situa un divisor por cada edificio, repartiendo la seal directamente hasta la vivienda.';...
        '- El segundo situa el divisor en cada edificio y se distribuye la seal hasta cada planta, donde hay otro divisor que reparte dicha seal hasta cada vivienda'},...
        'Parmetros del edificio','help');
elseif strcmp(valor,'ok'),
    
    % Al pulsar OK, se toman todos los datos introducidos por el usuario,
    % guardados en la variable global y se calcula la longitud de la fibra
    % hasta el hogar que se encuentra ms alejado
    
    a=str2double(get(DATOS(1),'string'));
    b=str2double(get(DATOS(2),'string'));
    c=str2double(get(DATOS(3),'string'));
    n=str2double(get(DATOS(4),'string'));
    v=str2double(get(DATOS(5),'string'));
    e=str2double(get(DATOS(6),'string'));
    div_ed=get(DATOS(7),'value');
    div_pl=get(DATOS(8),'value');
    if b>c,
        l=n*a+b*(v/(v/2))+c;
    elseif b<=c,
        l=n*a+b+c*(v/(v/2));
    end
    distr=1; % Este valor va a indicar que la distribucin que utilizo es de edificios
    tramo_largo=l;
    tramo_corto=(a+b+c)/2;
    if div_ed==1,
        info_div=1; % indica que solo hay 1 etapa de divisin
    elseif div_pl==1,
        info_div=2; % indica que hay 2 etapas de divisin
    end
    save variables distr n v e tramo_largo tramo_corto info_div ediv pr seg ter enl1 enl2 enl3 bp ep gp div2x2_1 div2x2_2 div2x2_3;
    close(gcf);
    configuracion_divisores;
    
elseif strcmp(valor,'volver'),
    close(gcf);
    distribucion;
end